aboutsummaryrefslogtreecommitdiff
path: root/src/jifsec.s
diff options
context:
space:
mode:
Diffstat (limited to 'src/jifsec.s')
-rw-r--r--src/jifsec.s10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/jifsec.s b/src/jifsec.s
index ca5aac7..86648c1 100644
--- a/src/jifsec.s
+++ b/src/jifsec.s
@@ -1,13 +1,13 @@
; print jiffies as seconds, with possible decimal point, to the
; active screen.
; unsigned divide based on Ullrich von Bassewitz's runtime/udiv.s.
; uses FR0 as a temp, rather than any of cc65's ZP storage,
; to avoid clobbering.
- FR0 = $d4
- acc16 = FR0 ; 16 bits
- remainder = FR0+2 ; 8 bits
- temp = FR0+3 ; 16 bits
+ FR1 = $e0
+ acc16 = FR1 ; 16 bits
+ remainder = FR1+2 ; 8 bits
+ temp = FR1+3 ; 16 bits
_hz = $f0 ; must agree with timers.h!
@@ -1,13 +1,13 @@
; active screen.
; unsigned divide based on Ullrich von Bassewitz's runtime/udiv.s.
-; uses FR0 as a temp, rather than any of cc65's ZP storage,
+; uses FR1 as a temp, rather than any of cc65's ZP storage,
; to avoid clobbering.